summaryrefslogtreecommitdiffhomepage
path: root/grammer.h
diff options
context:
space:
mode:
Diffstat (limited to 'grammer.h')
-rw-r--r--grammer.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/grammer.h b/grammer.h
index bdb2718..c2eb705 100644
--- a/grammer.h
+++ b/grammer.h
@@ -38,8 +38,8 @@ private:
BNF &bnf; // not const for access via operator[]
const std::string& Top;
- std::map<std::string, std::set<std::string>> ReverseBNF; // possible parent types of a given type
-
+ std::map<std::string, std::set<std::string>> ReverseBNF; // possible parent types of a given type; unused now: remove?
+ std::map<std::string, std::set<std::string>> reversedFirst; // possible parent types of first childs of a given type
// Tree specific
void clear();